<?php
/*
Plugin Name: Dtravel Booking
Plugin URI: https://wordpress.org/plugins/dtravel-booking-widget/
Description: Dtravel Booking get Tour or Hotel information and display on website.
Author: Nick Dtravel
Version: 1.1.3
Author URI: https://profiles.wordpress.org/nickdtravel/
Text Domain: dtravel-booking-widget
Domain Path: /languages
 */

// Block direct requests
if ( ! defined( 'ABSPATH' ) ) {
    die( '-1' );
}

// Load the widget on widgets_init
add_action('widgets_init', 'dtravel_booking_widget');
function dtravel_booking_widget()
{
    register_widget('Dtravel_Booking_Widget');
}

class Dtravel_Booking_Widget extends WP_Widget
{

    function __construct()
    {
        load_plugin_textdomain( 'dtravel-booking-widget', false, trailingslashit( basename( dirname( __FILE__ ) ) ) . 'languages/' );
        parent::__construct(
            'dtravel_booking_widget',
            'Dtravel Booking Widget',
            array(
                'description' => __('Dtravel Booking get Tour or Hotel information and display on website','dtravel-booking-widget'),
            )
        );
        define('WPDBW_PLUGIN_DIR_URL', plugin_dir_url(__FILE__));
        define('WPDBW_PLUGIN_SERVER_PATH', dirname( __FILE__ ) );
        define('WPDBW_VERSION', '1.1.3');
        require_once WPDBW_PLUGIN_SERVER_PATH . '/includes/tax.php';
        require_once WPDBW_PLUGIN_SERVER_PATH . '/includes/custom-field.php';
        add_action('wp_enqueue_scripts', array($this, 'enqueue_fe_scripts'));
    }

    function form($instance)
    {
        $instance = wp_parse_args($instance, array(
            'dtravel_token' =>  'dtravel_token',
        ));
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('dtravel_user_id')); ?>"><?php esc_html_e('Dtravel user id','dtravel-booking-widget'); ?></label>
            <input id="<?php echo esc_attr($this->get_field_id('dtravel_user_id')); ?>" type="text" name="<?php echo esc_attr($this->get_field_name('dtravel_user_id')); ?>" value="<?php echo esc_attr($instance['dtravel_user_id']); ?>"/>
        </p>
        <?php
    }

    function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['dtravel_user_id'] = strip_tags($new_instance['dtravel_user_id']);
        if (!get_option('dtravel_user_value_widget')) {
            add_option('dtravel_user_value_widget', $instance['dtravel_user_id']);
        } else {
            update_option('dtravel_user_value_widget', $instance['dtravel_user_id']);
        }
        return $instance;
    }


    function widget($args, $instance)
    {
        extract($args);
        echo $before_widget;
        $post_id = get_the_ID();
        $dtravel_property_id = (int)get_post_meta( $post_id, 'dtravel_property_id', true );
        $dtravel_user_id = $instance['dtravel_user_id'];
        $price = 0;
        $currency_code = '$';
        if ($dtravel_user_id && $dtravel_property_id) {
            $args = array(
                'timeout' => 30,
                'redirection' => 30,
                'httpversion' => '1.0',
                'user-agent' => 'WordPress/' . $GLOBALS['wp_version'] . '; ' . home_url(),
                'blocking' => true,
                'headers' => array('content-type' => 'application/json'),
                'cookies' => array(),
                'body' => null,
                'compress' => false,
                'decompress' => true,
                'sslverify' => true,
                'stream' => false,
                'filename' => null,
            );
            $url_get_listing = 'https://api-v3.dtravel.com/listing-service/v2/property/' . $dtravel_user_id . '/' . $dtravel_property_id;
            $response_get_listing = wp_remote_get($url_get_listing, $args);
            $data_get_listing = json_decode(wp_remote_retrieve_body($response_get_listing));
            $person_capacity = null;
            $max_children = null;
            $max_infants = null;
            $max_pets = null;
            $min_nights = 1;
            $max_nights = 365;
            $is_active = false;
            if ($data_get_listing && $data_get_listing->success === true && $data_get_listing->data) {
                $result = $data_get_listing->data;
                $person_capacity = $result->personCapacity;
                $max_children = $result->maxChildren;
                $max_infants = $result->maxInfant;
                $max_pets = $result->maxPet;
                $min_nights = $result->minNights;
                $max_nights = $result->maxNights;
                $is_active = true;
            }
            $now = new DateTime();
            $body = array(
                'checkinDate' => $now->format('Y-m-d'),
                'checkoutDate' => $now->modify('+'.$max_nights.' day')->format('Y-m-d'),
                'listingId' => $dtravel_property_id,
                'guestCount' => 1,
                'adults' => 1,
                'children' => 0,
                'infants' => 0,
                'pets' => 0,
                'currency' => 'USD',
            );
            $args['body'] = json_encode($body);
            $url = 'https://api-v3.dtravel.com/listing-service/calendar/price';
            $response = wp_remote_post($url, $args);
            $data = json_decode(wp_remote_retrieve_body($response));
            if ($data && $data->success === true && $data->data) {
                $data_calendar = $data->data;
                $price = $data_calendar->convertedPricePerNight->USD;
                $unavailable_date = array_filter($data_calendar->calendar, function ($obj) {
                    if ($obj->isAvailable == 0) {
                        return true;
                    }
                    return false;
                });
                $unavailable_date_arr = array_map(function ($o) {
                    return $o->date;
                }, $unavailable_date);
                $data_transfer = array(
                    'invalidDate' => $unavailable_date_arr,
                    'isActive' => $is_active,
                    'propertyDtravelId' => $dtravel_property_id,
                    'currency' => '$',
                    'minNights' => $min_nights,
                    'maxNights' => $max_nights,
                    'maxPets' => $max_pets,
                    'maxInfants' => $max_infants,
                    'maxChildren' => $max_children,
                    'personCapacity' => $person_capacity,
                    'userId' => $dtravel_user_id,
                );
            }
            wp_register_script('invalid_date', WPDBW_PLUGIN_DIR_URL . 'dtravel-booking-widget.php');
            wp_localize_script('invalid_date', 'dataTransfer', $data_transfer);
            wp_enqueue_script('invalid_date');
            ?>
            <div class="booking-calendar-widget">
                <div class="final-price">
                    <span class="pernight_label"><?php esc_html_e($currency_code.number_format($price, 2).' '.'per night','dtravel-booking-widget'); ?></span>
                </div>
                <div class="booking-form-request">
                    <h3><?php esc_html_e('Book Now','dtravel-booking-widget'); ?></h3>
                    <div class="input-group date-calendar">
                        <input type="text" class="form-control check-in-date" placeholder="Dates" data-startDate="" data-endDate="">
                        <div class="input-group-addon calendar-icon">
                            <span class="glyphicon glyphicon-calendar">
                                <img src="<?php echo esc_url(WPDBW_PLUGIN_DIR_URL.'assets/images/calendar-days-solid.svg')?>" alt="<?php esc_html_e('Date','dtravel-booking-widget');?>"/>
                            </span>
                        </div>
                    </div>
                    <div class="guest-number">
                        <div class="guest-number-wraper">
                            <div class="form-control guest-final"><?php esc_html_e('1 guest','dtravel-booking-widget'); ?></div>
                            <input type="hidden" name="guest-number" class="guest-input" value="1">
                            <div class="input-group-addon calendar-icon icon-guest">
                                <span class="glyphicon glyphicon-user">
                                    <img src="<?php echo esc_url(WPDBW_PLUGIN_DIR_URL.'assets/images/user-solid.svg')?>" alt="<?php esc_html_e('Date','dtravel-booking-widget');?>"/>
                                </span>
                            </div>
                            <div class="guest-popup" style="display: none">
                                <div class="guest-adults wrap-element">
                                    <div class="guest-labels">
                                        <div class="guest-title"><?php esc_html_e('Adults','dtravel-booking-widget'); ?></div>
                                        <div class="guest-description"><?php esc_html_e('Ages 13 or above','dtravel-booking-widget'); ?></div>
                                    </div>
                                    <div class="control-adults button-number">
                                        <button class="adults-minus control-button minus" data-element="adults">
                                            <svg width="13" height="6" viewBox="0 0 13 8" fill="none"
                                                 xmlns="http://www.w3.org/2000/svg">
                                                <path d="M0 0V2H13V0H0Z" fill="#5D6475"></path>
                                            </svg>
                                        </button>
                                        <div class="adults-value value">1</div>
                                        <button class="adults-plus control-button plus" data-element="adults">
                                            <svg width="13" height="13" viewBox="0 0 13 16" fill="none"
                                                 xmlns="http://www.w3.org/2000/svg">
                                                <path d="M5.6875 0V5.6875H0V7.3125H5.6875V13H7.3125V7.3125H13V5.6875H7.3125V0H5.6875Z"
                                                      fill="#5D6475"></path>
                                            </svg>
                                        </button>
                                        <input type="hidden" class="adults-input" name="adults-number" value="1">
                                    </div>
                                </div>
                                <div class="guest-childs wrap-element">
                                    <div class="guest-labels">
                                        <div class="guest-title"><?php esc_html_e('Children','dtravel-booking-widget'); ?></div>
                                        <div class="guest-description"><?php esc_html_e('Ages 2 to 12','dtravel-booking-widget'); ?></div>
                                    </div>
                                    <div class="control-childs button-number">
                                        <button class="childs-minus control-button minus" data-element="children">
                                            <svg width="13" height="6" viewBox="0 0 13 8" fill="none"
                                                 xmlns="http://www.w3.org/2000/svg">
                                                <path d="M0 0V2H13V0H0Z" fill="#5D6475"></path>
                                            </svg>
                                        </button>
                                        <div class="childs-value value">0</div>
                                        <button class="childs-plus control-button plus" data-element="children">
                                            <svg width="13" height="13" viewBox="0 0 13 16" fill="none"
                                                 xmlns="http://www.w3.org/2000/svg">
                                                <path d="M5.6875 0V5.6875H0V7.3125H5.6875V13H7.3125V7.3125H13V5.6875H7.3125V0H5.6875Z"
                                                      fill="#5D6475"></path>
                                            </svg>
                                        </button>
                                        <input type="hidden" class="childs-input" name="childs-number" value="0">
                                    </div>
                                </div>
                                <div class="guest-infants wrap-element">
                                    <div class="guest-labels">
                                        <div class="guest-title"><?php esc_html_e('Infants','dtravel-booking-widget'); ?></div>
                                        <div class="guest-description"><?php esc_html_e('Under 2 years','dtravel-booking-widget'); ?></div>
                                    </div>
                                    <div class="control-infants button-number">
                                        <button class="infants-minus control-button ignore-minus" data-element="infants">
                                            <svg width="13" height="6" viewBox="0 0 13 8" fill="none"
                                                 xmlns="http://www.w3.org/2000/svg">
                                                <path d="M0 0V2H13V0H0Z" fill="#5D6475"></path>
                                            </svg>
                                        </button>
                                        <div class="infants-value value">0</div>
                                        <button class="infants-plus control-button ignore-plus" data-element="infants">
                                            <svg width="13" height="13" viewBox="0 0 13 16" fill="none"
                                                 xmlns="http://www.w3.org/2000/svg">
                                                <path d="M5.6875 0V5.6875H0V7.3125H5.6875V13H7.3125V7.3125H13V5.6875H7.3125V0H5.6875Z"
                                                      fill="#5D6475"></path>
                                            </svg>
                                        </button>
                                        <input type="hidden" class="infants-input" name="infants-number" value="0">
                                    </div>
                                </div>
                                <div class="guest-pets wrap-element">
                                    <div class="guest-labels">
                                        <div class="guest-title"><?php esc_html_e('Pets','dtravel-booking-widget'); ?></div>
                                    </div>
                                    <div class="control-pets button-number">
                                        <button class="ignore-minus control-button" data-element="pets">
                                            <svg width="13" height="6" viewBox="0 0 13 8" fill="none"
                                                 xmlns="http://www.w3.org/2000/svg">
                                                <path d="M0 0V2H13V0H0Z" fill="#5D6475"></path>
                                            </svg>
                                        </button>
                                        <div class="pets-value value">0</div>
                                        <button class="ignore-plus control-button" data-element="pets">
                                            <svg width="13" height="13" viewBox="0 0 13 16" fill="none"
                                                 xmlns="http://www.w3.org/2000/svg">
                                                <path d="M5.6875 0V5.6875H0V7.3125H5.6875V13H7.3125V7.3125H13V5.6875H7.3125V0H5.6875Z"
                                                      fill="#5D6475"></path>
                                            </svg>
                                        </button>
                                        <input type="hidden" class="pets-input" name="pets-number" value="0">
                                    </div>
                                </div>
                                <div class="text-right flex justify-content-end">
                                    <button class="btn text-white flex items-center justify-center btn-primary apply-guest" data-guest="" data-adult="" data-child="" data-infant="" data-pet="">Apply</button>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="tax-fee"></div>
                    <button class="booking-button" disabled><?php esc_html_e('Reserve','dtravel-booking-widget'); ?></button>
                </div>
            </div>
            <?php
            if (!$data || !$data->success || !$data_get_listing || !$data_get_listing->success) {
                ?>
                <p class="error-message"><?php esc_html_e('Get price fail!','dtravel-booking-widget'); ?></p>
                <?php
            }
        }
        echo $after_widget;
    }

    public function enqueue_fe_scripts()
    {
        wp_register_style('dtravel_booking_widget-wpdbw-style', WPDBW_PLUGIN_DIR_URL . 'assets/css/style-fe.css', array(), 1.0, 'all');
        wp_enqueue_style('dtravel_booking_widget-wpdbw-style');

        wp_register_style('dtravel_booking_widget-bootstrap', WPDBW_PLUGIN_DIR_URL .'assets/css/bootstrap.min.css',false);
        wp_enqueue_style('dtravel_booking_widget-bootstrap');

        wp_register_style('dtravel_booking_widget-datepicker', WPDBW_PLUGIN_DIR_URL .'assets/css/bootstrap-datepicker.css');
        wp_enqueue_style('dtravel_booking_widget-datepicker');

        wp_register_style('dtravel_booking_widget-date_range_picker', WPDBW_PLUGIN_DIR_URL .'assets/css/daterangepicker.css');
        wp_enqueue_style('dtravel_booking_widget-date_range_picker');

        wp_register_script('dtravel_booking_widget-js-bootstrap', WPDBW_PLUGIN_DIR_URL. 'assets/js/bootstrap.min.js', array('jquery'), false, $in_footer = true);
        wp_enqueue_script('dtravel_booking_widget-js-bootstrap');

        wp_register_script('dtravel_booking_widget-js-moment', WPDBW_PLUGIN_DIR_URL. 'assets/js/moment.min.js', array(), false, $in_footer = true);
        wp_enqueue_script('dtravel_booking_widget-js-moment');

        wp_register_script('dtravel_booking_widget-js_date_range_picker', WPDBW_PLUGIN_DIR_URL. 'assets/js/daterangepicker.js', array(), false, $in_footer = true);
        wp_enqueue_script('dtravel_booking_widget-js_date_range_picker');

        wp_register_script('dtravel_booking_widget-tail_wind',WPDBW_PLUGIN_DIR_URL. 'assets/js/tailwind.js', array(), false, $in_footer = true);
        wp_enqueue_script('dtravel_booking_widget-tail_wind');

        wp_register_script('dtravel_booking_widget-wpdbw-script', WPDBW_PLUGIN_DIR_URL . 'assets/js/script-fe.js', array(), false);
        wp_enqueue_script('dtravel_booking_widget-wpdbw-script');
        wp_localize_script( 'dtravel_booking_widget-wpdbw-script', 'data_script', array(
                'ajaxUrl' => admin_url( 'admin-ajax.php' ),
            )
        );
    }
}

?>