<?php
add_action( 'wp_ajax_nopriv_dtravel_booking_widget_calculate_tax', 'dtravel_booking_widget_calculate_tax' );
add_action( 'wp_ajax_dtravel_booking_widget_calculate_tax', 'dtravel_booking_widget_calculate_tax' );
function dtravel_booking_widget_calculate_tax()
{
    $start_date = sanitize_text_field($_POST['start_date']);
    $end_date = sanitize_text_field($_POST['end_date']);
    $number_guest = intval($_POST['number_guest']) == 0 ? 1 : intval($_POST['number_guest']);
    $adults = intval($_POST['adults']) == 0 ? 1 : intval($_POST['adults']);
    $children = intval($_POST['children']);
    $infants = intval($_POST['infants']);
    $pets = intval($_POST['pets']);
    $property_dtravel_id = sanitize_text_field($_POST['property_dtravel_id']);
    $currency = sanitize_text_field($_POST['currency']);
    $body = array(
        'checkinDate' => $start_date,
        'checkoutDate' => $end_date,
        'listingId' => (int)$property_dtravel_id,
        'guestCount' => $number_guest,
        'adults' => $adults,
        'children' => $children,
        'infants' => $infants,
        'pets' => $pets,
        'currency' => 'USD',
    );
    $args = array(
        'timeout' => 30,
        'redirection' => 30,
        'httpversion' => '1.0',
        'user-agent' => 'WordPress/' . $GLOBALS['wp_version'] . '; ' . home_url(),
        'blocking' => true,
        'headers' => array('content-type' => 'application/json'),
        'cookies' => array(),
        'body' => json_encode($body),
        'compress' => false,
        'decompress' => true,
        'sslverify' => true,
        'stream' => false,
        'filename' => null,
    );
    $url = 'https://api-v3.dtravel.com/listing-service/calendar/price';
    $response = wp_remote_post($url, $args);
    $data = json_decode(wp_remote_retrieve_body($response));
    if ($data && $data->success === true && $data->data) {
        $result = $data->data;
        $base_price = $result->convertedPrice->USD;
        $total_price = $result->finalPrice->USD;
        $price_per_night = $result->convertedBasePricePerNight->USD;
        $date1 = new DateTime($start_date);
        $date2 = new DateTime($end_date);
        $interval = $date1->diff($date2);
        $number_night = $interval->days;
        $price_detail = $result->priceDetail;
        $arr_fee = $price_detail && $price_detail->fee ? $price_detail->fee : array();
        $arr_tax = $price_detail && $price_detail->tax ? $price_detail->tax : array();
        $arr_discount = $price_detail && $price_detail->discount ? $price_detail->discount : array();
        $fees = array_filter($arr_fee, function ($obj) {
            if ($obj->isIncludedInTotalPrice === true && $obj->name !== 'Credit card processing fee') {
                return true;
            }
            return false;
        });
        $taxes = array_filter($arr_tax, function ($obj) {
            if ($obj->isIncludedInTotalPrice === true) {
                return true;
            }
            return false;
        });
        $discounts = array_filter($arr_discount, function ($obj) {
            if ($obj->isIncludedInTotalPrice === true && $obj->name !== 'creditCardFeesAbsorbedByHost') {
                return true;
            }
            return false;
        });
        ?>
        <div class="bg-trasparient text-neutral-600 px-4 py-[24px] rounded-[16px] bg-neutral-200  mt-4">
            <div class="flex justify-between mb-[8px]">
                <div>
                    <div class="flex items-start">
                        <div class="w-auto flex items-start text-neutral-600">
                            <p class="text-14-18 font-inter-400" ><span class="whitespace-nowrap price-per-night" data-price-per-night="<?php echo esc_html($currency.number_format($price_per_night,2)); ?>">
                                <?php echo esc_html($currency.number_format($price_per_night,2)); ?> </span > <?php esc_html_e('x','dtravel-booking-widget'); echo esc_html($number_night); ?> <?php esc_html_e('night(s)','dtravel-booking-widget'); ?>
                            </p>
                        </div >
                    </div >
                </div>
                <span class="text-14-18 text-neutral-900 font-inter-500">
                <span class="whitespace-nowrap" > <?php echo esc_html($currency.number_format($base_price,2)); ?> </span>
            </span>
            </div>
            <?php
            foreach ($fees as $fee) {
                ?>
                <div class="flex justify-between mb-[8px]">
                    <div>
                        <div class="flex items-start">
                            <div class="w-auto flex items-start  text-neutral-600">
                                <p class="text-14-18 font-inter-400" > <?php echo esc_html($fee->title ?: $fee->name); ?></p>
                            </div>
                        </div>
                    </div>
                    <span class="text-14-18 text-neutral-900 font-inter-500">
                    <span class="whitespace-nowrap"> <?php echo esc_html($currency.number_format($fee->convertedValue->USD, 2)); ?> </span>
                </span>
                </div>
                <?php
            }
            foreach ($taxes as $tax) {
                ?>
                <div class="flex justify-between mb-[8px]">
                    <div>
                        <div class="flex items-start">
                            <div class="w-auto flex items-start text-neutral-600">
                                <p class="text-14-18 font-inter-400" > <?php echo esc_html($tax->title ?: $tax->name); ?> </p>
                            </div>
                        </div>
                    </div>
                    <span class="text-14-18 text-neutral-900 font-inter-500">
                        <span class="whitespace-nowrap"> <?php echo esc_html($currency.number_format($tax->convertedValue->USD, 2)); ?> </span>
                    </span>
                </div>
                <?php
            }
            foreach ($discounts as $discount) {
                ?>
                <div class="flex justify-between mb-[8px]">
                    <div>
                        <div class="flex items-start">
                            <div class="w-auto flex items-start text-neutral-600">
                                <p class="text-14-18 font-inter-400" > <? echo esc_html($discount->title ?: $discount->name); ?> </p>
                            </div>
                        </div>
                    </div>
                    <span class="text-14-18 text-neutral-900 font-inter-500">
                        <span class="whitespace-nowrap"> <? echo esc_html($currency.number_format($discount->convertedValue->USD    , 2)); ?> </span>
                    </span>
                </div>
                <?php
            }
            ?>
            <div class="h-[1px] bg-neutral-300 my-[16px]"></div>
            <div class="flex justify-between text-16-20">
                <span class="font-inter-500 text-neutral-900"> <?php esc_html_e('Total','dtravel-booking-widget'); ?></span>
                <span class="flex flex-col items-end">
                <span class="font-inter-500 text-neutral-900">
                    <span class="whitespace-nowrap"> <?php echo esc_html($currency.number_format($total_price,2)); ?> </span>
                </span>
            </span>
            </div>
        </div>
        <?php
    } else {
        ?>
        <p class="error-message"><?php esc_html_e('Some thing went wrong!','dtravel-booking-widget'); ?></p>
        <?php
    }
    exit();
}
?>